# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

Данный модуль предназначен для интеграции с АПК Бастион 3 версии. ВОзможно интеграция как через Бастион-ИКС,
так и через web-socket.